import {beforeAll, describe, expect, test} from '@jest/globals'
import {Utils} from '@/Utils/Utils'
import {PayError, Payment, PayType} from '@/Payment/Payment'
import {defaultRequest, DefaultResponse} from "@/Request/Request";
import {ACCESS_TOKEN, UID} from "@/Const";

const globalDatabase: any = {
    /**
     * 1块钱商品
     * https://testnewm.ydl.com/consult/#/pages/jieyou/DownOrder?product_id=88220606058062&uid=130959612&accessToken=33441f9c4be74a357b1d416d4aa616eaMjIwNw&ffrom=m
     */
    MOCK_GOODS: {
        orderId: 94220829005145,
        productId: 88220606058062,
        productSpecs: [
            {
                standardProductSpecId: 255539,
                amount: 1
            }
        ],
        type: 1,
        totalPrice: 1
    }
}

const createOrder = async (): Promise<{ orderId: number, title: string, payId: number, money: number }> => {
    const res = await defaultRequest.post<any, DefaultResponse>('https://testapi.ydl.com/api/consult/user/order/submitWorriesConsultOrder', globalDatabase.MOCK_GOODS)
    return res.data
}

beforeAll(async () => {
    //
    /**
     * 测试账号：15706780002 ydl123456
     * 请保证账户余额为0元
     */
    Utils.setCookie(UID, '130960056')
    Utils.setCookie(ACCESS_TOKEN, 'eccf89e37fb96ef67c4c2cfbe53a05ceMjIwNw')
    globalDatabase.payment = new Payment({
        wx_appId: "wx2bc3e1648beb8caa",
        zfb_appId: "2021002115687047"
    })
})


describe('测试无余额支付情况', () => {
    test('test：获取账户余额', async () => {
        const balance = await globalDatabase.payment.getBalance()
        expect(balance).toBe(1.99)
    })

    test('test: 测试余额支付', async () => {
        const res = await globalDatabase.payment.toPay({
            totalAmount: 3,
            payType: PayType.BALANCE,
            orderId: globalDatabase.MOCK_GOODS.orderId,
            redirectUrl: window.encodeURIComponent('https://www.baidu.com'),
            returnUrl: 'https://www.baidu.com',
            quitUrl: 'https://www.baidu.com'
        })
        expect(res.success).toBe(false)
        expect(res.errorMessage).toBe('余额不足')
    })
})

describe('测试无余额使用支付宝支付', () => {
    test('test: 使用支付宝支付', async () => {
        const {orderId, money} = await createOrder()
        const res = await globalDatabase.payment.toPay({
            totalAmount: money,
            payType: PayType.ALIPAY,
            orderId,
            redirectUrl: window.encodeURIComponent('https://www.baidu.com'),
            returnUrl: 'https://www.baidu.com',
            quitUrl: 'https://www.baidu.com'
        })
        expect(res.success).toBe(false)
        expect(res.errorType).toBe(PayError.ALIPAY_H5_BREAK)
    })
})

describe('测试无余额使用微信支付', () => {
    test('test: 使用微信支付', async () => {
        const {orderId, money} = await createOrder()
        const res = await globalDatabase.payment.toPay({
            totalAmount: money,
            payType: PayType.WECHAT,
            orderId,
            redirectUrl: window.encodeURIComponent('https://www.baidu.com'),
            returnUrl: 'https://www.baidu.com',
            quitUrl: 'https://www.baidu.com'
        })
        expect(res.success).toBe(false)
        expect(res.errorType).toBe(PayError.WECHAT_H5_BREAK)
    })
})